@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
 
-# $Id: defrag.pl,v 1.12 2000/12/31 12:51:59 rvsutherland Exp $
+# $Id: defrag.pl,v 1.13 2001/01/01 12:59:52 rvsutherland Exp $
 #
 # Copyright (c) 2000 Richard Sutherland - United States of America
 #
@@ -566,8 +566,13 @@ foreach $row( @$aref )
   {
     $create_ndx_ddl .= "PROMPT " .
                        "ANALYZE INDEX \L$owner.$index\n\n" .
-                       "ANALYZE INDEX \L$owner.$index \UESTIMATE STATISTICS\n" .
-                       "   FOR ALL INDEXED COLUMNS ;\n\n";
+                       "ANALYZE INDEX \L$owner.$index\n" .
+                       "   ESTIMATE STATISTICS ;\n\n" .
+                       "PROMPT " .
+                       "ANALYZE TABLE \L$owner.$table\n\n" .
+                       "ANALYZE TABLE \L$owner.$table\n" .
+                       "   ESTIMATE STATISTICS " .
+                       "FOR ALL INDEXED COLUMNS ;\n\n";
   }
 }
 
@@ -853,13 +858,13 @@ if ( $create_temp_ddl )
   # My linux Oracle 8.1.6 has a bug, so
   $prttn_exp_text .= "direct       = y\n"    unless $OSNAME eq 'linux';
 
-  $prttn_exp_text .= "buffer       = 65536\n" .
+  $prttn_exp_text .= "buffer       = 65535\n" .
                      "indexes      = n\n" .
                      "compress     = n\n" .
                      "triggers     = y\n" .
-                     "statistics   = n\n" .
+                     "statistics   = none\n" .
                      "constraints  = n\n" .
-                     "recordlength = 65536\n" .
+                     "recordlength = 65535\n" .
                      "tables       = (\n" .
                      "                   " .
                      join ( "\n                 , ", @export_temps ) .
@@ -875,9 +880,9 @@ if ( $create_temp_ddl )
                     "rows         = y\n" .
                     "commit       = y\n" .
                     "ignore       = y\n" .
-                    "buffer       = 65536\n" .
+                    "buffer       = 65535\n" .
                     "analyze      = n\n" .
-                    "recordlength = 65536\n" .
+                    "recordlength = 65535\n" .
                     "full         = y\n\n" .
                     "#tables       = (\n" .
                     "#                   " .
@@ -898,13 +903,13 @@ my $exp_text  = "log          = $exp_log\n" .
   # My linux Oracle 8.1.6 has a bug, so
    $exp_text .= "direct       = y\n"    unless $OSNAME eq 'linux';
 
-   $exp_text .= "buffer       = 65536\n" .
+   $exp_text .= "buffer       = 65535\n" .
                 "indexes      = n\n" .
                 "compress     = n\n" .
                 "triggers     = y\n" .
-                "statistics   = n\n" .
+                "statistics   = none\n" .
                 "constraints  = n\n" .
-                "recordlength = 65536\n" .
+                "recordlength = 65535\n" .
                 "tables       = (\n" .
                 "                   " .
                 join ( "\n                 , ", @export_objects ) .
@@ -920,9 +925,9 @@ my $imp_text = "log          = $imp_log\n" .
                "rows         = y\n" .
                "commit       = y\n" .
                "ignore       = y\n" .
-               "buffer       = 65536\n" .
+               "buffer       = 65535\n" .
                "analyze      = n\n" .
-               "recordlength = 65536\n" .
+               "recordlength = 65535\n" .
                "full         = y\n\n" .
                "#tables       = (\n" .
                "#                   " .
@@ -2373,61 +2378,6 @@ sub write_header
             "$remark on ", scalar localtime,"\n\n\n\n";
 }
 
-# $Log: defrag.pl,v $
-# Revision 1.12  2000/12/31 12:51:59  rvsutherland
-# Added ANALYZE TABLE/INDEX following Import, for previously analyzed objects
-#
-# Revision 1.11  2000/12/31 00:46:58  rvsutherland
-# Before starting, verified that Log files were writiable.
-# Modified queries in anticipation of adding ANALYZE TABLE statements
-#
-# Revision 1.10  2000/12/28 21:45:25  rvsutherland
-# Upgraded to handle table names containing '$'.
-# Corrected Statement Group 15 to MOVE the partitions back to THE TABLESPACE.
-# Put all Log files in logdir (were going to sqldir -- go figure)
-# Corrected NEXT size if object reached last tier (was null)
-#
-# Revision 1.9  2000/12/09 17:38:56  rvsutherland
-# Additional tuning refinements.
-# Minor cleanup of code.
-#
-# Revision 1.8  2000/12/06 00:43:45  rvsutherland
-# Significant performance improvements.
-# No, make that MAJOR gains (i.e., orders of magnitude for large databases).
-# To wit:
-#   Replaced convoluted Dictionary views with 8i Temporary Tables
-#   Widely (but not entirely) switched to bind variables (was interpolated,
-#     causing reparsing in most cases).
-# Also fixed error on REBUILD of Global and non-partitioned indexes.
-#
-# Revision 1.7  2000/12/02 14:06:20  rvsutherland
-# Completed 'exchange' method for handling partitions,
-# including REBUILD of UNUSABLE indexes.
-# Removed 'resize' method for handling partitions.
-#
-# Revision 1.6  2000/11/26 20:10:54  rvsutherland
-# Added 'exchange' method for handling partitions.  Will probably
-# remove the 'resize' method next update.
-#
-# Revision 1.5  2000/11/24 18:36:00  rvsutherland
-# Restructured file writes
-# Revamped 'resize' method for handling partitions
-#
-# Revision 1.4  2000/11/19 20:08:58  rvsutherland
-# Added 'resize' partitions option.
-# Restructured file creation.
-# Added shell scripts to simplify executing generated files.
-# Modified selection of IOT tables (now handled same as indexes)
-# Added validation of input arguments -- meaning we now check for
-# hanging chad and pregnant votes  ;-)
-#
-# Revision 1.3  2000/11/17 21:35:53  rvsutherland
-# Commented out Direct Path export -- Import has a bug (at least on Linux)
-#
-# Revision 1.2  2000/11/16 09:14:38  rvsutherland
-# Major restructure to take advantage of DDL::Oracle.pm
-#
-
 __END__
 
 ########################################################################
